/*
 *    AudioDBWrapper.java
 *    Copyright (C) 2011 New Zealand Digital Library, http://www.nzdl.org
 *
 *    This program is free software; you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation; either version 2 of the License, or
 *    (at your option) any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program; if not, write to the Free Software
 *    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
package org.greenstone.gsdl3.util;

import java.io.File;
import java.util.Vector;

/** java wrapper class for access to the audioDB executable
 *
 * Inspired by MGSearchWrapper.java
 */

public class AudioDBWrapper
{
    /** the query result, filled in by runQuery */
    protected Vector query_result_ = null;

    protected int offset_ = 100;
    protected int length_ = 20;
    
    // Approximate matching not yet utilized
    protected double radius_;

    protected int max_docs_;

    public AudioDBWrapper() {  
	query_result_ = new Vector();
    }

    // query param methods

    /** start point (offset) into the array of feature vectors for a track 
	- 100 by default which equals 10 seconds (assuming 0.1 frame size) */
    public void setOffset(int offset) {
	offset_ = offset;
    }
	
    /** the number of consecutive frames used in match
	- 20 by default which equals 2 seconds (assuming 0.1 frame size) */
    public void setLength(int length) {
	length_ = length;
    }

    /** distance used in approximate matching support - default is 50 */
    public void setRadius(double radius) {
	radius_ = radius;
    }

    public void setMaxDocs(int max_docs) {
	max_docs_ = max_docs;
    }

    /** returns a string with all the current query param settings */
    // the following was in MG version, do we need this in audioDB version?
    //public String getQueryParams() {}

    /** actually carry out the query.
	Use the set methods to set query results.
	Writes the result to query_result.
     * - maintains state between requests as can be slow  
     * base_dir and index_path should join together to provide
     * the absolute location of the mg index files eg ..../index/dtx/demo 
     * base_dir must end with a file separator (OS dependant)
     */
    public void runQuery(String index_dir, String adb_file, String query_string) {

	// combine index_dir with audiodb fileanem

	String full_adb_filename  = index_dir + File.separatorChar + adb_file;

	String cmd = "audioDB"
	    + " -d " + full_adb_filename
	    + " -Q sequence"
	    + " -p " + offset_ 
	    + " -n 1"
	    + " -l " + length_
	    + " -r " + "numMatchingDocs"
	    + " -f " + "track.chr12";


    }


    /** get the result out of the wrapper */
    public Vector getQueryResult()
    {
	return query_result_;
    }
}

